@@ -1,16 +1,10 @@
 use strict;
 use warnings;
 package Search::GIN::Driver;
-BEGIN {
-  $Search::GIN::Driver::AUTHORITY = 'cpan:NUFFIN';
-}
-# ABSTRACT:
-$Search::GIN::Driver::VERSION = '0.09';
+our $VERSION = '0.10';
 use Moose::Role;
-
 use Data::Stream::Bulk::Util qw(bulk nil cat unique);
-
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 requires qw(
     insert_entry
@@ -82,36 +76,3 @@ sub fetch_entries_all {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Search::GIN::Driver - $Search::GIN::Driver::VERSION = '0.09';
-
-=head1 VERSION
-
-version 0.09
-
-=head1 SYNOPSIS
-
-    use Search::GIN::Driver;
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
