@@ -1,19 +1,12 @@
 use strict;
 use warnings;
 package Search::GIN::Driver::Hash;
-BEGIN {
-  $Search::GIN::Driver::Hash::AUTHORITY = 'cpan:NUFFIN';
-}
-# ABSTRACT:
-$Search::GIN::Driver::Hash::VERSION = '0.09';
+our $VERSION = '0.10';
 use Moose::Role;
-
 use Set::Object;
-
 use Data::Stream::Bulk::Util qw(bulk);
 use Scalar::Util qw(refaddr);
-
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 with qw(Search::GIN::Driver);
 
@@ -84,30 +77,3 @@ sub insert_entry {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Search::GIN::Driver::Hash - $Search::GIN::Driver::Hash::VERSION = '0.09';
-
-=head1 VERSION
-
-version 0.09
-
-=head1 AUTHOR
-
-יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
