@@ -1,14 +1,10 @@
 use strict;
 use warnings;
 package Search::GIN::Driver::Pack::UUID;
-BEGIN {
-  $Search::GIN::Driver::Pack::UUID::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: UUID key packing
-$Search::GIN::Driver::Pack::UUID::VERSION = '0.09';
+our $VERSION = '0.10';
 use Moose::Role;
-
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 with qw(Search::GIN::Driver);
 
@@ -36,13 +32,7 @@ Search::GIN::Driver::Pack::UUID - UUID key packing
 
 =head1 VERSION
 
-version 0.09
-
-=head1 SYNOPSIS
-
-    use Search::GIN::Driver::PackUUID;
-
-=head1 DESCRIPTION
+version 0.10
 
 =head1 AUTHOR
 
