@@ -1,18 +1,11 @@
 use strict;
 use warnings;
 package Search::GIN::Driver::TXN;
-BEGIN {
-  $Search::GIN::Driver::TXN::AUTHORITY = 'cpan:NUFFIN';
-}
-# ABSTRACT:
-$Search::GIN::Driver::TXN::VERSION = '0.09';
+our $VERSION = '0.10';
 use Moose::Role;
-
 use Scope::Guard;
-
 use Carp qw(croak);
-
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 with qw(Search::GIN::Driver);
 
@@ -82,36 +75,3 @@ sub txn_do {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Search::GIN::Driver::TXN - $Search::GIN::Driver::TXN::VERSION = '0.09';
-
-=head1 VERSION
-
-version 0.09
-
-=head1 SYNOPSIS
-
-    use Search::GIN::Driver::TXN;
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
