@@ -1,13 +1,9 @@
 use strict;
 use warnings;
 package Search::GIN::Extract::Attributes;
-BEGIN {
-  $Search::GIN::Extract::Attributes::VERSION = '0.08';
-}
-# ABSTRACT:
-
+our $VERSION = '0.10';
 use Moose;
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 with qw(
     Search::GIN::Extract
@@ -44,39 +40,6 @@ sub get_meta_attrs {
     }
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
-
-
-
-=pod
-
-=head1 NAME
-
-Search::GIN::Extract::Attributes - use Moose;
-
-=head1 VERSION
-
-version 0.08
-
-=head1 SYNOPSIS
-
-	use Search::GIN::Extract::Attributes;
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-Yuval Kogman <nothingmuch@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-
-__END__
-
