@@ -1,14 +1,10 @@
 use strict;
 use warnings;
 package Search::GIN::Keys::Expand;
-BEGIN {
-  $Search::GIN::Keys::Expand::VERSION = '0.08';
-}
-# ABSTRACT:
-
+our $VERSION = '0.10';
 use Moose::Role;
 use Carp qw(croak);
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 sub expand_keys {
     my ( $self, @keys ) = @_;
@@ -54,31 +50,3 @@ sub expand_keys_hash {
 }
 
 1;
-
-
-
-=pod
-
-=head1 NAME
-
-Search::GIN::Keys::Expand - use Moose::Role;
-
-=head1 VERSION
-
-version 0.08
-
-=head1 AUTHOR
-
-Yuval Kogman <nothingmuch@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-
-__END__
