@@ -1,14 +1,11 @@
 use strict;
 use warnings;
 package Search::GIN::Query::Attributes;
-BEGIN {
-  $Search::GIN::Query::Attributes::VERSION = '0.08';
-}
 # ABSTRACT: Create attributes-based GIN queries
-
+our $VERSION = '0.10';
 use Moose;
 use Carp qw(croak);
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 with qw(
     Search::GIN::Query
@@ -84,17 +81,19 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Search::GIN::Query::Attributes - Create attributes-based GIN queries
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -135,17 +134,13 @@ Attributes of the object you want to find.
 
 =head1 AUTHOR
 
-Yuval Kogman <nothingmuch@cpan.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman), Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
