@@ -1,14 +1,11 @@
 use strict;
 use warnings;
 package Search::GIN::Query::Class;
-BEGIN {
-  $Search::GIN::Query::Class::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: Create class-based GIN queries
-$Search::GIN::Query::Class::VERSION = '0.09';
+our $VERSION = '0.10';
 use Moose;
 use Carp qw(croak);
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
 with qw(
     Search::GIN::Query
@@ -107,7 +104,7 @@ Search::GIN::Query::Class - Create class-based GIN queries
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
